@@ -1,7 +1,7 @@
-__version__ = "0.0.31"
+__version__ = "0.0.33"
 
 from .face_detection import detect_face
-from .object_detection import detect_common_objects
+from .object_detection import detect_common_objects, TFlite, YOLO
 from .gender_detection import detect_gender
 from .utils import get_frames, animate
 from .object_tracker import Track
