@@ -61,7 +61,7 @@ def draw_bbox(img, bbox, labels, confidence, colors=None, write_conf=False):
 
     return img
     
-def detect_common_objects(image, confidence=0.5, nms_thresh=0.3, model='yolov4', enable_gpu=False):
+def detect_common_objects(image, confidence=0.5, nms_thresh=0.3, model='yolov4-tiny', enable_gpu=False):
     """A method to detect common objects
     Args:
         image: A colour image in a numpy array
@@ -268,3 +268,49 @@ class YOLO:
 
             cv2.putText(img, label, (bbox[i][0],bbox[i][1]-10), cv2.FONT_HERSHEY_SIMPLEX, 0.5, color, 2)
 
+class TFlite:
+    def __init__(self, tflite_model, coconames):
+        import tensorflow as tf
+        self.interpreter = tf.lite.Interpreter(model_path=tflite_model)
+        self.interpreter.allocate_tensors()
+        with open(coconames, 'r') as f:
+            self.labels = [line.strip() for line in f.readlines()]
+        # Get input and output tensors.
+        self.input_details = self.interpreter.get_input_details()
+        self.output_details = self.interpreter.get_output_details()
+        # Test the TensorFlow Lite model on random input data.
+        self.height = self.input_details[0]['shape'][1]
+        self.width = self.input_details[0]['shape'][2]
+        self.floating_model = (self.input_details[0]['dtype'] == np.float32)
+        self.input_mean = 127.5
+        self.input_std = 127.5
+
+    def detect_objects(self, img, min_conf_threshold = 0.5):
+        frame_resized = cv2.resize(img, (self.width, self.height))
+        frame_rgb = cv2.cvtColor(frame_resized, cv2.COLOR_BGR2RGB)
+        input_data = np.expand_dims(frame_resized, axis=0)
+
+        # Normalize pixel values if using a floating model (i.e. if model is non-quantized)
+        if self.floating_model:
+            input_data = (np.float32(input_data) - self.input_mean) / self.input_std
+
+        # Perform the actual detection by running the model with the image as input
+        self.interpreter.set_tensor(self.input_details[0]['index'], input_data)
+        self.interpreter.invoke()
+
+        # Bounding box coordinates of detected objects
+        boxes = self.interpreter.get_tensor(self.output_details[0]['index'])[0]
+        classes = self.interpreter.get_tensor(self.output_details[1]['index'])[0]
+        scores = self.interpreter.get_tensor(self.output_details[2]['index'])[0]
+
+        for i in range(len(scores)):
+            if (scores[i] > min_conf_threshold) and (scores[i] <= 1.0):
+                ymin = int(max(1, (boxes[i][0] * self.height)))
+                xmin = int(max(1, (boxes[i][1] * self.width)))
+                ymax = int(min(self.height, (boxes[i][2] * self.height)))
+                xmax = int(min(self.width, (boxes[i][3] * self.width)))
+                cv2.rectangle(frame_resized, (xmin, ymin),(xmax, ymax), (10, 255, 0), 2)
+                object_name = self.labels[int(classes[i])]
+                cv2.putText(frame_resized, object_name, (xmin,ymin-10), cv2.FONT_HERSHEY_SIMPLEX, 0.5, (200,35,95), 2)
+
+        return frame_resized
